@@ -1,5 +1,5 @@
 /* 
- * Copyright 1999-2008, Gisle Aas
+ * Copyright 1999-2009, Gisle Aas
  * Copyright 1999-2000, Michael A. Chase
  *
  * This library is free software; you can redistribute it and/or
@@ -1847,7 +1847,7 @@ parse(pTHX_
 		warn("Parsing of undecoded UTF-8 will give garbage when decoding entities");
 	    }
 	    if (utf8 && len >= 2 && strnEQ(beg, "\xFF\xFE", 2)) {
-		warn("Parsing string decoded with wrong endianess");
+		warn("Parsing string decoded with wrong endianness");
 	    }
 #endif
 	    if (!utf8 && len >= 4 &&
